@@ -36,7 +36,7 @@ import tokenize
 import untokenize
 
 
-__version__ = '0.5.5'
+__version__ = '0.5.6'
 
 
 try:
@@ -210,8 +210,7 @@ def is_probably_beginning_of_sentence(line):
         if re.search(r'\s' + token + r'\s', line):
             return True
 
-    character = line.strip()[0]
-    return not character.isalnum()
+    return re.match(r'[^\w"\'`]', line.strip())
 
 
 def split_summary_and_description(contents):
@@ -363,13 +362,12 @@ def wrap_description(text, indentation, wrap_length):
 
     """
     text = strip_leading_blank_lines(text)
+    text = remove_section_header(text)
 
     # Do not modify doctests at all.
     if '>>>' in text:
         return text
 
-    text = remove_section_header(text)
-
     text = reindent(text, indentation).rstrip()
 
     # Ignore possibly complicated cases.
@@ -503,7 +501,7 @@ def main(argv, standard_out, standard_error):
     while filenames:
         name = filenames.pop(0)
         if args.recursive and os.path.isdir(name):
-            for root, directories, children in os.walk(name):
+            for root, directories, children in os.walk(unicode(name)):
                 filenames += [os.path.join(root, f) for f in children
                               if f.endswith('.py') and
                               not f.startswith('.')]
